@@ -38,10 +38,6 @@
 # Main configuration file
 # -----------------------------------
 
-# MREST_CLI_URI_BASE
-#     URI of the App::Dochazka::REST server
-set( 'MREST_CLI_URI_BASE', 'http://localhost:5000' );
-
 # DOCHAZKA_REST_LOGIN_NICK
 #     nick to use when we authenticate ourselves to the App::Dochazka::REST server
 #     when this is set to '' or undef, App::Dochazka::CLI will prompt for it
