@@ -38,9 +38,10 @@ use strict;
 use warnings;
 
 use App::CELL qw( $CELL $log );
-use App::Dochazka::CLI qw( $current_emp $debug_mode );
+use App::Dochazka::CLI qw( $current_emp $current_priv $debug_mode );
 use App::Dochazka::CLI::Util qw( 
     determine_employee
+    lookup_employee
     parse_test 
     refresh_current_emp 
     rest_error 
@@ -65,6 +66,8 @@ App::Dochazka::CLI::Commands::Employee - Employee commands
 =cut
 
 our @EXPORT_OK = qw( 
+    employee_ldap
+    employee_ldap_import
     employee_list
     employee_profile
     employee_team
@@ -105,36 +108,110 @@ sub employee_profile {
     my $emp = $status->payload;
 
     # determine supervisor
-    my $supervisor_nick;
+    my $supervisor = App::Dochazka::Common::Model::Employee->spawn();
     if ( my $supervisor_eid = $emp->supervisor ) {
         $status = determine_employee( "EMPL=$supervisor_eid" );
-        if ( $status->ok and $status->payload ) {
-            $supervisor_nick = $status->payload->nick;
+        if ( $status->ok ) {
+            $supervisor = $status->payload;
+        } else {
+            $log->warn( "Failed to look up supervisor by EID $supervisor_eid; error was " . $status->text );
         }
     }
 
-    # GET priv/eid/:eid
-    $status = send_req( 'GET', 'priv/eid/' . $emp->eid );
-    return rest_error( $status, "Determine employee privlevel" ) unless $status->ok;
-    my $priv = $status->payload->{'priv'};
-
-    my $message;
-    $message = "\nEmployee profile\n================\n\n";
+    my $message = "\n";
     $message .= "Full name:    " . ( $emp->fullname ? $emp->fullname : "(not set)" ) . "\n";
     $message .= "Nick:         " . $emp->nick . "\n";
+    $message .= "Email:        " . ( $emp->email || "(not set)" ) . "\n";
     $message .= "Secondary ID: " . ( $emp->sec_id ? $emp->sec_id : "(not set)" ) . "\n";
     $message .= "Dochazka EID: " . $emp->eid . "\n";
-    $message .= "Password*:    (" . ( $emp->passhash ? "set" : "not set" ) . ")\n";
-    $message .= "Privlevel:    $priv\n";
-    $message .= "Reports to:   " . ( $supervisor_nick ? $supervisor_nick : "(not set)" ) . "\n";
-    $message .= "\n";
-    $message .= "* Internal password stored in the Dochazka database - \n";
-    $message .= "  irrelevant if external authentication in use.\n";
+    $message .= "Reports to:   " . ( $supervisor->nick || "(not set)" ) . "\n";
 
     return $CELL->status_ok( 'DOCHAZKA_CLI_NORMAL_COMPLETION', payload => $message );
 }
 
 
+=head3 employee_ldap
+
+    EMPLOYEE LDAP
+    EMPLOYEE_SPEC LDAP
+
+=cut
+
+sub employee_ldap {
+    print "Entering " . __PACKAGE__ . "::employee_ldap\n" if $debug_mode;
+    my ( $ts, $th ) = @_;
+
+    # parse test
+    return parse_test( $ts, $th ) if $ts eq 'PARSE_TEST';
+
+    # determine nick
+    my $nick;
+    if ( my $spec = $th->{'EMPLOYEE_SPEC'} ) {
+        # other; just take whatever is after the '='
+        ( $nick ) = $spec =~ m/=(.+)$/;
+    } else {
+        # self; get $nick from $current_emp
+        $nick = $current_emp->nick;
+    }
+
+    # send the request 
+    my $status = send_req( 'GET', "employee/nick/$nick/ldap" );
+    return $status unless $status->ok;
+
+    # success: spawn and populate object
+    my $emp = App::Dochazka::Common::Model::Employee->spawn(
+        %{ $status->payload }
+    );
+
+    my $message = "\n";
+    $message .= "Nick:              " . $emp->nick . "\n";
+    $message .= "LDAP full name:    " . ( $emp->fullname ? $emp->fullname : "(not set)" ) . "\n";
+    $message .= "LDAP email:        " . ( $emp->email || "(not set)" ) . "\n";
+    $message .= "LDAP secondary ID: " . ( $emp->sec_id ? $emp->sec_id : "(not set)" ) . "\n";
+    
+    if ( $current_priv eq 'admin' ) {
+        # determine if employee already exists in Dochazka database
+        my $status = send_req( 'GET', "employee/nick/" . $emp->nick . "/minimal" );
+        if ( $status->level eq 'OK' and $status->code eq 'DOCHAZKA_EMPLOYEE_MINIMAL' ) {
+            my $nick = $status->payload->{'nick'};
+            my $eid = $status->payload->{'eid'};
+            $message .= "\nEmployee $nick already exists in Dochazka with EID $eid\n";
+        } else {
+            my $nick = $emp->nick;
+            $message .= "\nEmployee $nick is missing in Dochazka; to import, do \"EMPL=$nick LDAP IMPORT\"\n";
+        }
+    }
+
+    return $CELL->status_ok( 'DOCHAZKA_CLI_NORMAL_COMPLETION', payload => $message );
+}
+
+
+=head3 employee_ldap_import
+
+    EMPLOYEE_SPEC LDAP IMPORT
+
+=cut
+
+sub employee_ldap_import {
+    print "Entering " . __PACKAGE__ . "::employee_ldap_import\n" if $debug_mode;
+    my ( $ts, $th ) = @_;
+
+    # parse test
+    return parse_test( $ts, $th ) if $ts eq 'PARSE_TEST';
+
+    # determine nick
+    my ( $nick ) = $th->{'EMPLOYEE_SPEC'} =~ m/=(.+)$/;
+
+    # send the request
+    my $status = send_req( 'PUT', "employee/nick/$nick/ldap" );
+    if ( $status->level eq 'OK' and $status->code eq 'DOCHAZKA_CUD_OK' ) {
+        return employee_profile( $ts, $th );
+    } else {
+        return $status;
+    }
+}
+
+    
 =head3 employee_list
 
 EMPLOYEE LIST
