@@ -39,7 +39,7 @@ use strict;
 use warnings;
 
 use App::CELL qw( $CELL $log $meta $site );
-use App::Dochazka qw( $t $today $tomorrow $yesterday init_timepiece );
+use App::Dochazka::Common qw( $t $today $tomorrow $yesterday init_timepiece );
 use App::Dochazka::CLI qw( 
     $current_emp 
     $current_priv 
@@ -102,13 +102,13 @@ server goes via the C<send_req> routine in L<Web::MREST::CLI::UserAgent>. This
 routine takes its connection parameters (address of REST server, nick and
 password) from the following configuration parameters:
 
-    $site->MREST_CLI_URI_BASE
+    $meta->MREST_CLI_URI_BASE
     $meta->CURRENT_EMPLOYEE_NICK
     $meta->CURRENT_EMPLOYEE_PASSWORD
 
-The first parameter, C<MREST_CLI_URI_BASE>, is a site configuration parameter
-so it is assumed to be loaded from a configuration file. The second and third
-are meta parameters and are set by this routine.
+The first parameter, C<MREST_CLI_URI_BASE>, is assumed to be set before this
+routine is called. The second and third are meta parameters and are set by
+this routine.
 
 After setting the meta parameters, the routine causes a GET request for the
 C<employee/self/priv> resource to be send to the server, and uses the response
@@ -144,17 +144,6 @@ sub authenticate_to_server {
     $meta->set( 'CURRENT_EMPLOYEE_NICK', $PROPLIST{'user'} );
     $meta->set( 'CURRENT_EMPLOYEE_PASSWORD', $PROPLIST{'password'} );
 
-    ## prompt for password if necessary
-    #if ( ! $PROPLIST{'quiet'} and $PROPLIST{'user'} ne 'demo' and $PROPLIST{'password'} eq 'demo' ) {
-    #    print "Server auth password: ";
-    #    my $input = <STDIN>;
-    #    chomp( $input ); 
-    #    $meta->set( 'CURRENT_EMPLOYEE_PASSWORD', $input );
-    #    #print "Password set to " . $meta->CURRENT_EMPLOYEE_PASSWORD . "\n";
-    #} else {
-    #    $meta->set( 'CURRENT_EMPLOYEE_PASSWORD', $PROPLIST{'password'} );
-    #}
-
     # get info about us
     my $status;
     try {
@@ -190,7 +179,7 @@ sub determine_employee {
     my $s_key = shift;
 
     my $status = ( $s_key )
-        ? lookup_employee( $s_key )
+        ? lookup_employee( key => $s_key, minimal => 1 )
         : refresh_current_emp();
     return ( $status->ok )
         ? $CELL->status_ok( 'EMPLOYEE_LOOKUP', 
@@ -208,29 +197,35 @@ EMPLOYEE_SPEC may be "nick=...", "sec_id=...", "eid=...", or simply
 =cut
 
 sub lookup_employee {
-    my ( $s_key ) = validate_pos( @_, { type => SCALAR } );
-    print "Entering " . __PACKAGE__ . "::lookup_employee with search key " . Dumper( $s_key )
+    my %ARGS = validate( @_, 
+        {
+            key => { type => SCALAR },
+            minimal => { default => 0 },     
+        }
+    );
+    print "Entering " . __PACKAGE__ . "::lookup_employee with search key " . Dumper( $ARGS{key} )
         if $debug_mode;
 
-    die( "AH! Not an EMPLOYEE_SPEC" ) unless $s_key =~ m/=/;
+    die( "AH! Not an EMPLOYEE_SPEC" ) unless $ARGS{key} =~ m/=/;
 
-    my ( $key_spec, $key ) = $s_key =~ m/^(.*)\=(.*)$/;
+    my ( $key_spec, $key ) = $ARGS{key} =~ m/^(.*)\=(.*)$/;
+    my $minimal = $ARGS{minimal} ? '/minimal' : '';
 
     my $status;
     if ( $key_spec =~ m/^emp/i ) {
-        $status = send_req( 'GET', "employee/nick/$key" );
+        $status = send_req( 'GET', "employee/nick/$key$minimal" );
         if ( $status->not_ok and ( $status->{'http_code'} == 404 or $status->{'http_code'} == 403 ) ) {
-            $status = send_req( 'GET', "employee/sec_id/$key" );
+            $status = send_req( 'GET', "employee/sec_id/$key$minimal" );
             if ( $status->not_ok and $status->{'http_code'} != 500 and looks_like_number( $key ) ) {
-                $status = send_req( 'GET', "employee/eid/$key" );
+                $status = send_req( 'GET', "employee/eid/$key$minimal" );
             }
         }
     } elsif ( $key_spec =~ m/^nic/i ) {
-        $status = send_req( 'GET', "employee/nick/$key" );
+        $status = send_req( 'GET', "employee/nick/$key$minimal" );
     } elsif ( $key_spec =~ m/^sec/i ) {
-        $status = send_req( 'GET', "employee/sec_id/$key" );
+        $status = send_req( 'GET', "employee/sec_id/$key$minimal" );
     } elsif ( $key_spec =~ m/^eid/i ) {
-        $status = send_req( 'GET', "employee/eid/$key" );
+        $status = send_req( 'GET', "employee/eid/$key$minimal" );
     } else {
         die "AAAHAAAHHH!!! Invalid employee lookup key " . ( defined( $key_spec ) ? $key_spec : "undefined" )
     }
